package net.omnis.android.ui.main

import android.content.Intent
import android.os.Bundle
import android.view.*
import androidx.lifecycle.ViewModelProviders
import net.omnis.android.MainActivity
import net.omnis.android.OmnisController
import net.omnis.android.R
import net.omnis.android.settings.OMSettings
import net.omnis.android.about.About
import net.omnis.android.about.CreditsActivity
import net.omnis.android.notifications.OmnisNotification


class MainFragment : OMImmersiveFragment() { // jmg0950

	private lateinit var mOmnisController: OmnisController

	companion object {
		fun newInstance() = MainFragment()
	}

	private lateinit var viewModel: MainViewModel

	override fun onCreateView(inflater: LayoutInflater, container: ViewGroup?,
														savedInstanceState: Bundle?): View {
		return inflater.inflate(R.layout.main_fragment, container, false)
	}

	override fun onActivityCreated(savedInstanceState: Bundle?) {
		super.onActivityCreated(savedInstanceState)
		viewModel = ViewModelProviders.of(this).get(MainViewModel::class.java)

		setHasOptionsMenu(true)
		checkImmersiveMode() // jmg0950
	}

	override fun onStart() {
		super.onStart()
		if (!this::mOmnisController.isInitialized) {
			mOmnisController = OmnisController(activity!!, view!!.findViewById(R.id.omweb_container))
			viewModel.setOmnisController(mOmnisController)
			mOmnisController.loadForm()
		}

	}

	override fun onResume() {
		super.onResume()
		checkForNotificationIntent()
	}

	private fun checkForNotificationIntent() {
		val intent = activity?.intent

		if (intent != null) {

			if (intent.hasExtra("_OMNIS_NOTIFICATION_")) { // This was triggered by clicking on a notification which had a data payload.
				intent.removeExtra("_OMNIS_NOTIFICATION_")

				val urlParams = mutableMapOf<String, String>()
				val extras = OmnisNotification.removeExtraDataFromPayload(intent.extras!!) // jmg0593

				for (key in extras.keySet()) {
					urlParams[key] = extras.getString(key) ?: ""
				}

				mOmnisController.loadForm(urlParams)
			}
		}
	}

	override fun onCreateOptionsMenu(menu: Menu?, inflater: MenuInflater?) {
		inflater?.inflate(R.menu.menu, menu)
	}

	override fun onPrepareOptionsMenu(menu: Menu?) {
		super.onPrepareOptionsMenu(menu)

		menu?.findItem(R.id.menuOnlineMode)?.isChecked = mOmnisController.getOnlineMode()

		menu?.findItem(R.id.menuUpdateApp)?.isVisible = (OMSettings.getSettingBool(OMSettings.IDs.MENU_INCLUDE_UPDATE) ?: true) && !mOmnisController.getOnlineMode() // Only show the Update Application option in Offline mode. // jmg0890
		menu?.findItem(R.id.menuOnlineMode)?.isVisible = OMSettings.getSettingBool(OMSettings.IDs.MENU_INCLUDE_OFFLINE) ?: true // jmg0890

		val includeAbout = OMSettings.getSettingBool(OMSettings.IDs.MENU_INCLUDE_ABOUT) ?: true // jmg0890
		menu?.findItem(R.id.menuAbout)?.isVisible = includeAbout
		menu?.findItem(R.id.menuCredits)?.isVisible = !includeAbout
		menu?.findItem(R.id.menuSettings)?.isVisible = OMSettings.getSettingBool(OMSettings.IDs.MENU_INCLUDE_SETTINGS) ?: true // jmg0890
	}

	override fun onOptionsItemSelected(item: MenuItem?): Boolean {

		when (item?.itemId) {
			R.id.reload -> {
				mOmnisController.loadForm()
				return true
			}

			R.id.menuSettings -> {
				viewModel.showSettingsScreen(activity as MainActivity)
				return true
			}

			R.id.menuUpdateApp -> {
				mOmnisController.updateSCAFs()
			}

			R.id.menuOnlineMode -> {
				mOmnisController.setOnlineMode(!item.isChecked)
				mOmnisController.loadForm()
			}

			R.id.menuAbout -> {
				val aboutIntent = Intent(activity, About::class.java)
				startActivity(aboutIntent)
			}

			R.id.menuCredits -> {
				val creditsIntent = Intent(activity, CreditsActivity::class.java)
				startActivity(creditsIntent)
			}

		}

		return super.onOptionsItemSelected(item)
	}

}
