package net.omnis.android.ui.main

import android.app.Activity
import android.app.Application
import android.content.Intent
import androidx.lifecycle.AndroidViewModel
import net.omnis.android.OmnisController
import net.omnis.android.settings.OMSettings
import net.omnis.android.settings.SettingsActivity
import net.omnis.omnisinterface.IntentHelper

class MainViewModel(application: Application) : AndroidViewModel(application) {

	private lateinit var mOmnisController: OmnisController

	init {
		OMSettings.loadSettings(application)
	}

	fun setOmnisController(omnisController: OmnisController) {
		mOmnisController = omnisController
	}


	fun showSettingsScreen(activity: Activity) {
		val intent = Intent(activity, SettingsActivity::class.java)

		IntentHelper.startActivityForResult(activity, 1, intent, null) { requestCode, resultCode, data ->
			if (data!= null) {
				val changedSettings = data.getStringArrayExtra("changedSettings")
				val changedGroups = data.getStringArrayExtra("changedGroups")

				// If any of the changes made were related to offline mode, reinitialise offline mode:
				if (changedGroups.contains("offlinemode_settings") || changedSettings.containsAnyOf(OMSettings.IDs.OMNIS_WEB_URL))
					mOmnisController.reinitOfflineMode()

				// If the local DB name was changed, reinitialise the local database:
				if (changedSettings.contains(OMSettings.IDs.LOCAL_DB_NAME))
					mOmnisController.reinitLocalDB()
			}
		}
	}

	/**
	 * Extension function to check if an array contains any of the passed parameters.
	 */
	private fun <T> Array<T>.containsAnyOf(vararg tokens: T): Boolean
	{
		return this.any(tokens::contains)
	}
}
